@@ -235,7 +235,7 @@ SetProgramStats (FrontEndProgramStats * stats) // now directly called by back-en
         }
     }
 
-    if(ParseOneMove(ed.pv, currentMove, &moveType, &ff, &rf, &ft, &rt, &pc))
+    if(ed.pv && ed.pv[0] && ParseOneMove(ed.pv, currentMove, &moveType, &ff, &rf, &ft, &rt, &pc))
 	ed.moveKey = (ff<<24 | rf << 16 | ft << 8 | rt) ^ pc*87161;
     else ed.moveKey = ed.nodes; // kludge to get unique key unlikely to match any move
 
@@ -500,10 +500,10 @@ UpdateControls (EngineOutputData *ed)
         unsigned long nps_100 = ed->nodes / ed->time;
 
         if( nps_100 < 100000 ) {
-	  snprintf( s_label, sizeof(s_label)/sizeof(s_label[0]), "NPS: %lu", nps_100 * 100 );
+	  snprintf( s_label, sizeof(s_label)/sizeof(s_label[0]), "%s: %lu", _("NPS"), nps_100 * 100 );
         }
         else {
-	  snprintf( s_label, sizeof(s_label)/sizeof(s_label[0]), "NPS: %.1fk", nps_100 / 10.0 );
+	  snprintf( s_label, sizeof(s_label)/sizeof(s_label[0]), "%s: %.1fk", _("NPS"), nps_100 / 10.0 );
         }
     }
 
