@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
  *
  * XBoard borrows its colors and the bitmaps.xchess bitmap set from XChess,
  * which was written and is copyrighted by Wayne Christopher.
@@ -336,7 +336,7 @@ KeyboardEvent(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 		if(currentPiece != EmptySquare) {
 			char buf[MSG_SIZ];
 			n = boards[currentMove][fromY][1];
-			snprintf(buf, MSG_SIZ, "%d %s%s", n, _(PieceToName(currentPiece,0)), n == 1 ? "" : "s");
+			snprintf(buf, MSG_SIZ, "%d %s%s", n, PieceToName(currentPiece,0), n == 1 ? "" : "s");
 			SayString(buf, FALSE);
 		}
 		SayString(" ", TRUE);
@@ -346,7 +346,7 @@ KeyboardEvent(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 		if(currentPiece != EmptySquare) {
 			char buf[MSG_SIZ];
 			n = boards[currentMove][fromY][BOARD_WIDTH-2];
-			snprintf(buf, MSG_SIZ,"%d %s%s", n, _(PieceToName(currentPiece,0)), n == 1 ? "" : "s");
+			snprintf(buf, MSG_SIZ,"%d %s%s", n, PieceToName(currentPiece,0), n == 1 ? "" : "s");
 			SayString(buf, FALSE);
 		}
 		SayString(" ", TRUE);
@@ -356,8 +356,8 @@ KeyboardEvent(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 		xchar = SquareToChar(fromX);
 		ynum = SquareToNum(fromY);
 		if(currentPiece != EmptySquare) {
-		  snprintf(buf, MSG_SIZ, "%s %s %s", _(xchar), _(ynum), _(piece));
-		} else snprintf(buf, MSG_SIZ, "%s %s", _(xchar), _(ynum));
+		  snprintf(buf, MSG_SIZ, "%s %s %s", xchar, ynum, piece);
+		} else snprintf(buf, MSG_SIZ, "%s %s", xchar, ynum);
 		SayString(buf, FALSE);
 		SayString(" ", TRUE);
 	}
@@ -1240,9 +1240,8 @@ NiceTime(int x)
       }\
       return 0;\
 
-#define JAWS_KB_NAVIGATION \
+#define JAWS_KBDOWN_NAVIGATION \
 \
-	case WM_KEYDOWN:\
 \
 		if(GetKeyState(VK_MENU) < 0 && GetKeyState(VK_CONTROL) < 0) {\
 		    /* Control + Alt + letter used for speaking piece positions */\
@@ -1279,14 +1278,13 @@ NiceTime(int x)
 			KeyboardMove(hwnd, message, wParam, lParam);\
 			break;\
 		}\
-		break;\
-	case WM_KEYUP:\
+
+#define JAWS_KBUP_NAVIGATION \
 		switch (wParam) {\
 		case VK_SPACE:\
 			KeyboardMove(hwnd, message, wParam, lParam);\
 			break;\
 		}\
-		break;\
 
 #define JAWS_MENU_ITEMS \
 		case IDM_PossibleAttackMove:  /*What can I possible attack from here */\
