@@ -1,7 +1,7 @@
 /*
  * xedittags.c -- Tags edit window, part of X front end for XBoard
  *
- * Copyright 1995, 2009, 2010, 2011 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
@@ -93,32 +93,28 @@ extern char *getenv();
 
 Position tagsX = -1, tagsY = -1;
 
-void TagsPopUp(tags, msg)
-     char *tags, *msg;
+void
+TagsPopUp (char *tags, char *msg)
 {
     NewTagsPopup(tags, cmailMsgLoaded ? msg : NULL);
 }
 
 
-void EditTagsPopUp(tags, dest)
-     char *tags;
-     char **dest;
+void
+EditTagsPopUp (char *tags, char **dest)
 {
     NewTagsPopup(tags, NULL);
 }
 
-void TagsPopDown()
+void
+TagsPopDown()
 {
     PopDown(2);
     bookUp = False;
 }
 
 void
-EditTagsProc(w, event, prms, nprms)
-     Widget w;
-     XEvent *event;
-     String *prms;
-     Cardinal *nprms;
+EditTagsProc (Widget w, XEvent *event, String *prms, Cardinal *nprms)
 {
     Arg args[5];
     int j;
